==> haskell-xss-sanitize-0.3.6-212-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xss-sanitize.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xss-sanitize
version:              0.3.6
visibility:           public
id:                   xss-sanitize-0.3.6-Csf3Vv3wHbp3yt4uffBoHK
key:                  xss-sanitize-0.3.6-Csf3Vv3wHbp3yt4uffBoHK
license:              BSD-2-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Greg Weber <greg@gregweber.info>
stability:            Stable
homepage:             https://github.com/yesodweb/haskell-xss-sanitize#readme
synopsis:             sanitize untrusted HTML to prevent XSS attacks
description:
    run untrusted HTML through Text.HTML.SanitizeXSS.sanitizeXSS to prevent XSS attacks. see README.md <http://github.com/yesodweb/haskell-xss-sanitize> for more details

category:             Web
abi:                  e9662c73276cb1b7f81c3c6d8d48d953
exposed:              True
exposed-modules:      Text.HTML.SanitizeXSS
hidden-modules:       Text.HTML.SanitizeXSS.Css Paths_xss_sanitize
import-dirs:          /usr/lib/ghc-8.10.2/site-local/xss-sanitize-0.3.6
library-dirs:         /usr/lib/ghc-8.10.2/site-local/xss-sanitize-0.3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/xss-sanitize-0.3.6
hs-libraries:         HSxss-sanitize-0.3.6-Csf3Vv3wHbp3yt4uffBoHK
depends:
    attoparsec-0.13.2.4-6s9PGXpTa8d5vs3WhgDbsJ base-4.14.1.0
    containers-0.6.2.1 css-text-0.1.3.0-JoZ1WuEkjku4UoMxXDnEwN
    network-uri-2.6.3.0-IdwbPA3fhdYBhkOBZdgenv
    tagsoup-0.14.8-3Z3pFAyYj0W2GMnmSKLsKC text-1.2.3.2
    utf8-string-1.0.1.1-G1tzxDqsWge3erFqc4Oe2R

haddock-interfaces:
    /usr/share/doc/haskell-xss-sanitize/html/xss-sanitize.haddock

haddock-html:         /usr/share/doc/haskell-xss-sanitize/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xss-sanitize-0.3.6-213-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xss-sanitize.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xss-sanitize
version:              0.3.6
visibility:           public
id:                   xss-sanitize-0.3.6-2oQUlbPm8QAA0wr9tPFudS
key:                  xss-sanitize-0.3.6-2oQUlbPm8QAA0wr9tPFudS
license:              BSD-2-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Greg Weber <greg@gregweber.info>
stability:            Stable
homepage:             https://github.com/yesodweb/haskell-xss-sanitize#readme
synopsis:             sanitize untrusted HTML to prevent XSS attacks
description:
    run untrusted HTML through Text.HTML.SanitizeXSS.sanitizeXSS to prevent XSS attacks. see README.md <http://github.com/yesodweb/haskell-xss-sanitize> for more details

category:             Web
abi:                  4989d2379ee0740e19fbcb18e208a7fa
exposed:              True
exposed-modules:      Text.HTML.SanitizeXSS
hidden-modules:       Text.HTML.SanitizeXSS.Css Paths_xss_sanitize
import-dirs:          /usr/lib/ghc-8.10.2/site-local/xss-sanitize-0.3.6
library-dirs:         /usr/lib/ghc-8.10.2/site-local/xss-sanitize-0.3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/xss-sanitize-0.3.6
hs-libraries:         HSxss-sanitize-0.3.6-2oQUlbPm8QAA0wr9tPFudS
depends:
    attoparsec-0.13.2.4-6s9PGXpTa8d5vs3WhgDbsJ base-4.14.1.0
    containers-0.6.2.1 css-text-0.1.3.0-JoZ1WuEkjku4UoMxXDnEwN
    network-uri-2.6.3.0-6vWQyDUmR9F6Y6dEBYfPUD
    tagsoup-0.14.8-3Z3pFAyYj0W2GMnmSKLsKC text-1.2.3.2
    utf8-string-1.0.1.1-G1tzxDqsWge3erFqc4Oe2R

haddock-interfaces:
    /usr/share/doc/haskell-xss-sanitize/html/xss-sanitize.haddock

haddock-html:         /usr/share/doc/haskell-xss-sanitize/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
